==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SplineFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineFragmentDescription } from "./SplineFragmentDescription";
/**
 * @hidden
 */
export let SplineFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (SplineFragmentDescriptionMetadata.a == null) {
                SplineFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineFragmentDescriptionMetadata.c(SplineFragmentDescriptionMetadata.a);
            }
            if (a.k(SplineFragmentDescriptionMetadata.a)) {
                return;
            }
            a.ab(SplineFragmentDescriptionMetadata.a);
        }
        static c(a) {
            SplineFragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineFragmentDescriptionMetadata.b(a);
            a.ad("SplineFragment", () => new SplineFragmentDescription());
            a.ac("SplineFragment", SplineFragmentDescriptionMetadata.a);
        }
    }
    SplineFragmentDescriptionMetadata.$t = markType(SplineFragmentDescriptionMetadata, 'SplineFragmentDescriptionMetadata');
    SplineFragmentDescriptionMetadata.a = null;
    return SplineFragmentDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SplineFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineFragmentDescription } from "./SplineFragmentDescription";
/**
 * @hidden
 */
export let SplineFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (SplineFragmentDescriptionMetadata.a == null) {
                SplineFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineFragmentDescriptionMetadata.c(SplineFragmentDescriptionMetadata.a);
            }
            if (a.k(SplineFragmentDescriptionMetadata.a)) {
                return;
            }
            a.ac(SplineFragmentDescriptionMetadata.a);
        }
        static c(a) {
            SplineFragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineFragmentDescriptionMetadata.b(a);
            a.ae("SplineFragment", () => new SplineFragmentDescription());
            a.ad("SplineFragment", SplineFragmentDescriptionMetadata.a);
        }
    }
    SplineFragmentDescriptionMetadata.$t = markType(SplineFragmentDescriptionMetadata, 'SplineFragmentDescriptionMetadata');
    SplineFragmentDescriptionMetadata.a = null;
    return SplineFragmentDescriptionMetadata;
})();
